aboutsummaryrefslogtreecommitdiffstats
path: root/src/jogl/classes/com/jogamp/opengl/GLRendererQuirks.java
diff options
context:
space:
mode:
authorSven Gothel <[email protected]>2015-02-02 02:36:39 +0100
committerSven Gothel <[email protected]>2015-02-02 02:36:39 +0100
commit1ec82447e464d5308442581f14d32f9775928454 (patch)
treea43a08ee632ac0e57d866b8509189656a2f016e3 /src/jogl/classes/com/jogamp/opengl/GLRendererQuirks.java
parent2174059ed395ccb45c4a33a8bc7619abbf15f19e (diff)
Bug 682 - Relocating javax.media.opengl.* -> com.jogamp.opengl.* (Part 1)
sed -i 's/javax\.media\.opengl/com\.jogamp\.opengl/g' `grep -Rl "javax\.media\.opengl" src` sed -i 's/javax\.media\.nativewindow/com\.jogamp\.nativewindow/g' `grep -Rl "javax\.media\.nativewindow" src` sed -i 's/javax\/media\//com\/jogamp\//g' `grep -Rl "javax/media/" src` sed -i 's/javax\/media\//com\/jogamp\//g' `grep -Rl "javax/media/" doc` Manually edited all occurences within make/**
Diffstat (limited to 'src/jogl/classes/com/jogamp/opengl/GLRendererQuirks.java')
-rw-r--r--src/jogl/classes/com/jogamp/opengl/GLRendererQuirks.java8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/jogl/classes/com/jogamp/opengl/GLRendererQuirks.java b/src/jogl/classes/com/jogamp/opengl/GLRendererQuirks.java
index 9b973c626..55c02d92a 100644
--- a/src/jogl/classes/com/jogamp/opengl/GLRendererQuirks.java
+++ b/src/jogl/classes/com/jogamp/opengl/GLRendererQuirks.java
@@ -29,8 +29,8 @@ package com.jogamp.opengl;
import java.util.IdentityHashMap;
-import javax.media.nativewindow.AbstractGraphicsDevice;
-import javax.media.opengl.GLCapabilitiesImmutable;
+import com.jogamp.nativewindow.AbstractGraphicsDevice;
+import com.jogamp.opengl.GLCapabilitiesImmutable;
import com.jogamp.common.os.Platform;
import com.jogamp.opengl.egl.EGL;
@@ -347,7 +347,7 @@ public class GLRendererQuirks {
* Some drivers wrongly claim to support pbuffers
* with accumulation buffers. However, the creation of such pbuffer fails:
* <pre>
* javax.media.opengl.GLException: pbuffer creation error: Couldn't find a suitable pixel format
* </pre>
* </p>
* <p>
@@ -401,7 +401,7 @@ public class GLRendererQuirks {
* Some drivers wrongly claim to support ARB_create_context.
* However, the creation of such context fails:
* <pre>
* javax.media.opengl.GLException: AWT-EventQueue-0: WindowsWGLContex.createContextImpl ctx !ARB, profile > GL2
* requested (OpenGL >= 3.0.1). Requested: GLProfile[GL3bc/GL3bc.hw], current: 2.1 (Compat profile, FBO, hardware)
* - 2.1.8787
* </pre>
@@ -347,7 +347,7 @@ public class GLRendererQuirks {
* with accumulation buffers. However, the creation of such pbuffer fails:
* <pre>
- * javax.media.opengl.GLException: pbuffer creation error: Couldn't find a suitable pixel format
+ * com.jogamp.opengl.GLException: pbuffer creation error: Couldn't find a suitable pixel format
* </pre>
* </p>
@@ -401,7 +401,7 @@ public class GLRendererQuirks {
* However, the creation of such context fails:
* <pre>
- * javax.media.opengl.GLException: AWT-EventQueue-0: WindowsWGLContex.createContextImpl ctx !ARB, profile > GL2
+ * com.jogamp.opengl.GLException: AWT-EventQueue-0: WindowsWGLContex.createContextImpl ctx !ARB, profile > GL2
* requested (OpenGL >= 3.0.1). Requested: GLProfile[GL3bc/GL3bc.hw], current: 2.1 (Compat profile, FBO, hardware)
* - 2.1.8787